var dir_68267d1309a1af8e8297ef4c3efbcdba =
[
    [ "blas.f90", "blas_8f90_source.html", null ],
    [ "lapack.f90", "lapack_8f90_source.html", null ],
    [ "linalg.f90", "linalg_8f90_source.html", null ],
    [ "linalg_basic.f90", "linalg__basic_8f90_source.html", null ],
    [ "linalg_eigen.f90", "linalg__eigen_8f90_source.html", null ],
    [ "linalg_factor.f90", "linalg__factor_8f90_source.html", null ],
    [ "linalg_solve.f90", "linalg__solve_8f90_source.html", null ],
    [ "linalg_sorting.f90", "linalg__sorting_8f90_source.html", null ],
    [ "linalg_sparse.f90", "linalg__sparse_8f90_source.html", null ],
    [ "qrupdate.f90", "qrupdate_8f90_source.html", null ],
    [ "sparskit.f90", "sparskit_8f90_source.html", null ]
];